@@ -162,14 +162,15 @@ class Source {
                         Logger::warning('OR-ed versions are not supported %s:%s (%s) in file "%s".', $level, $project_package, $versions, $this->_path);
                     } else {
                         try {
+                            $operator_regexp = '(==?|!=|<>|>=?|<=?|~|\^)'; // $1
+                            $versions = preg_replace("/([^,])\s+$operator_regexp/", '\1,\2', $versions);
                             foreach(explode(',', $versions) as $version) {
                                 // Construct regexp
-                                $operator_regexp  = '(==?|!=|<>|>=?|<=?|~)?'; // $1
                                 $version_regexp   = 'v?([0-9.*]*|self\.version|dev-\w+)'; // $2
                                 $stability_regexp = '(-dev|-patch\d*|-alpha\d*|-beta\d*|-RC\d*)?'; // $3
                                 $stabilityflag_regexp = '((?i)@dev|@alpha|@beta|@RC|@stable)?'; // $4
                                 $inlinealias_regexp = '(?:\s+as\s+(\S+))?'; // $5
-                                if (preg_match("/^\s*$operator_regexp\s*$version_regexp$stability_regexp\s*$stabilityflag_regexp$inlinealias_regexp\s*$/", $version, $operator_matches)) {
+                                if (preg_match("/^\s*$operator_regexp?\s*$version_regexp$stability_regexp\s*$stabilityflag_regexp$inlinealias_regexp\s*$/", $version, $operator_matches)) {
                                     $operator = $operator_matches[1];
                                     $base_version = $operator_matches[2];
                                     if (!empty($operator_matches[3])) {
@@ -226,10 +227,28 @@ class Source {
                                 } elseif ($operator == '~') {
                                     // ~x.y.z -> (>= x.y.z), (<< x.y+1~~)
                                     $version_components = explode('.', $version);
-                                    array_pop($version_components);
-                                    $last_version_component = array_pop($version_components);
+                                    if (count($version_components) > 1) {
+                                        array_pop($version_components);
+                                        $last_version_component = array_pop($version_components);
+                                    } else {
+                                        $last_version_component = array_pop($version_components);
+                                    }
                                     $dep->minVersion = $version;
                                     $dep->maxVersion = implode('.', array_merge($version_components, Array($last_version_component + 1))) . '~~';
+                                } elseif ($operator == '^') {
+                                    // ^x.y.z -> (>= x.y.z), (<< x+1~~)   if x >= 1
+                                    // ^x.y.z -> (>= x.y.z), (<< x.y+1~~) if x == 0
+                                    $version_components = explode('.', $version);
+                                    $prefix_components = Array();
+                                    $significant_version_component = array_shift($version_components);
+                                    if ($significant_version_component == '0') {
+                                        array_unshift($prefix_components, $significant_version_component);
+                                        $significant_version_component = array_shift($version_components);
+                                    }
+                                    $dep->minVersion = $version;
+                                    $dep->maxVersion = implode('.', array_merge(
+                                        $prefix_components,
+                                        Array($significant_version_component + 1))). '~~';
                                 } else {
                                     throw new \InvalidArgumentException("Unable to parse version operator '$operator' with dependency $project_package ($versions)");
                                 }
