@@ -171,10 +171,10 @@ class Command extends \Pkgtools\Base\Command {
             ),
             $dependencies);
         // Print substvars
-        echo 'phppear:Debian-Depends='    . implode($dependencies['require'], ', ')."\n";
-        echo 'phppear:Debian-Recommends=' . implode($dependencies['recommend'], ', ')."\n";
-        echo 'phppear:Debian-Suggests='   . implode($dependencies['suggest'], ', ')."\n";
-        echo 'phppear:Debian-Breaks='     . implode($dependencies['conflict'], ', ')."\n";
+        echo 'phppear:Debian-Depends='    . implode(', ', $dependencies['require'])."\n";
+        echo 'phppear:Debian-Recommends=' . implode(', ', $dependencies['recommend'])."\n";
+        echo 'phppear:Debian-Suggests='   . implode(', ', $dependencies['suggest'])."\n";
+        echo 'phppear:Debian-Breaks='     . implode(', ', $dependencies['conflict'])."\n";
         $summary = $p->summary;
         if ($summary[strlen($summary)-1] == '.') {
             $summary = substr($summary, 0, -1);
