@@ -116,6 +116,47 @@ class Source {
         }
     }
 
+    /**
+     * Get maintainers
+     */
+    function getMaintainers() {
+        $ret = Array();
+        if ($this->_version == '1.0') {
+            foreach($this->_xml->maintainers as $maintainer) {
+                $ret[] = Array(
+                    'user'  => (string) $maintainer->user,
+                    'name'  => (string) $maintainer->name,
+                    'email' => (string) $maintainer->email,
+                    'role'  => (string) $maintainer->role,
+                );
+            }
+        } else {
+            foreach(Array('lead', 'developer', 'contributor', 'helper') as $role) {
+                foreach($this->_xml->{$role} as $maintainer) {
+                    $ret[] = Array(
+                        'user'   => (string) $maintainer->user,
+                        'name'   => (string) $maintainer->name,
+                        'email'  => (string) $maintainer->email,
+                        'role'   => (string) $role,
+                        'active' => (string) $maintainer->active,
+                    );
+                }
+            }
+		}
+		return $ret;
+    }
+
+    /**
+     * Get current date
+     */
+    function getDate() {
+        if ($this->_version == '1.0') {
+            return (string) $this->_xml->release->date;
+        } else {
+            return (string) $this->_xml->date;
+        }
+    }
+
     /**
      * Get current version
      *
@@ -129,6 +170,41 @@ class Source {
         }
     }
 
+    /**
+     * Get current stability
+     *
+     * @param string $key release|api
+     */
+    function getStability($key = 'release') {
+        if ($this->_version == '1.0') {
+            return (string) $this->_xml->release->state;
+        } else {
+            return (string) $this->_xml->stability->{$key};
+        }
+    }
+
+    /**
+     * Get current license
+     */
+    function getLicense() {
+        if ($this->_version == '1.0') {
+            return trim((string) $this->_xml->release->license);
+        } else {
+            return trim((string) $this->_xml->license);
+        }
+    }
+
+    /**
+     * Get current notes
+     */
+    function getNotes() {
+        if ($this->_version == '1.0') {
+            return trim((string) $this->_xml->release->notes);
+        } else {
+            return trim((string) $this->_xml->notes);
+        }
+    }
+
     /**
      * Get package type
      *
@@ -171,7 +247,7 @@ class Source {
      * Canonic version. ie:
      * x.ya1 -> x.y~a1
      */
-    function canonicVersion($version) {
+    static public function canonicVersion($version) {
         if (preg_match('/^(.*\d)(alpha\d*|a\d*|beta\d*|b\d*|rc\d*)$/i', $version, $matches)) {
             return $matches[1] . '~' . $matches[2];
         } else {
@@ -258,4 +334,43 @@ class Source {
         }
         return $result;
     }
+
+    /**
+     * Changelog
+     */
+    function getChangelog() {
+        $ret  = "Version ".$this->getVersion()." - ".$this->getDate()." (".$this->getStability().")\n";
+        $ret .= "----------------------------------------\n";
+        $ret .= "Notes:\n";
+        $ret .= "  ".str_replace("\n", "\n  ", wordwrap(preg_replace('/\s+/', ' ', $this->getNotes())))."\n\n";
+
+        if ($this->_version == '1.0') {
+            $releases = $this->_xml->xpath('p:changelog/p:release');
+            foreach($releases as $release) {
+                $ret .= "Version ".$release->version." - ".$release->date." (".$release->state.")\n";
+                $ret .= "----------------------------------------\n";
+                $ret .= "Notes:\n";
+                $ret .= "  ".str_replace("\n", "\n  ", wordwrap(preg_replace('/\s+/', " ", trim($release->notes))))."\n\n";
+            }
+        } else {
+            $this->_xml->registerXPathNamespace('p', 'http://pear.php.net/dtd/package-2.0');
+            $releases = $this->_xml->xpath('p:changelog/p:release');
+            $releases = array_reverse($releases);
+            foreach($releases as $release) {
+                $ret .= "Version ".$release->version->release." - ".$release->date." (".$release->stability->release.")\n";
+                $ret .= "----------------------------------------\n";
+                $ret .= "Notes:\n";
+                $ret .= "  ".str_replace("\n", "\n  ", wordwrap(preg_replace('/\s+/', ' ', trim($release->notes))))."\n\n";
+            }
+        }
+        return $ret;
+    }
+
+    /**
+     * Convert to a dependency
+     */
+    function asDependency($level = 'require') {
+        $dep = new \Pkgtools\Base\Dependency($level, 'pear-'.$this->channel, $this->name);
+        return $dep;
+    }
 }
