@@ -66,20 +66,16 @@ Commands:
         $this->_cli->parseArgs(Array('--help'));
     }
 
-    /**
-     * @expectedException LogicException
-     * @expectedExceptionMessage Unknown option --unknown
-     */
     public function testUnknownOption() {
+        $this->expectException('LogicException');
+        $this->expectExceptionMessage('Unknown option --unknown');
         $this->expectOutputString('');
         $this->_cli->parseArgs(Array('--unknown'));
     }
 
-    /**
-     * @expectedException LogicException
-     * @expectedExceptionMessage Unknown sub-command unknown
-     */
     public function testUnknownSubcommand() {
+        $this->expectException('LogicException');
+        $this->expectExceptionMessage('Unknown sub-command unknown');
         $this->expectOutputString('');
         $this->_cli->parseArgs(Array('unknown'));
     }
