@@ -13,7 +13,7 @@ my $testpecl = 'testsuite/data/peclpkg1';
 my $testchan = 'testsuite/data/pearchan1';
 
 # Init
-my $orig_dir = getcwd();
+my $sourcedir = getcwd();
 my $failures = 0;
 my $destdir;
 chdir($testpkg);
@@ -24,11 +24,11 @@ my $phppear;
 # CONFIGURE pearpkg1
 # =============================================================================
 $phppear = Debian::Debhelper::Buildsystem::phppear->new();
-$phppear->{phppkginfo_path} = "$orig_dir/share/pkg-php-tools/scripts/phppkginfo";
+$phppear->testmode($sourcedir);
 $phppear->pre_building_step();
 $phppear->configure();
-if (!-f "MyProject_Packages-0.0.1/package.xml") {
-	print "FAIL: File does not exists: MyProject_Packages-0.0.1/package.xml\n";
+if (!-f "MyProject_Packages-1.2.1/package.xml") {
+	print "FAIL: File does not exists: MyProject_Packages-1.2.1/package.xml\n";
 	$failures++;
 }
 
@@ -36,7 +36,7 @@ if (!-f "MyProject_Packages-0.0.1/package.xml") {
 # BUILD pearpkg1
 # =============================================================================
 $phppear = Debian::Debhelper::Buildsystem::phppear->new();
-$phppear->{phppkginfo_path} = "$orig_dir/share/pkg-php-tools/scripts/phppkginfo";
+$phppear->testmode($sourcedir);
 $phppear->pre_building_step();
 $phppear->build();
 
@@ -45,7 +45,7 @@ $phppear->build();
 # =============================================================================
 $destdir = tempdir( CLEANUP => 1 );
 $phppear = Debian::Debhelper::Buildsystem::phppear->new();
-$phppear->{phppkginfo_path} = "$orig_dir/share/pkg-php-tools/scripts/phppkginfo";
+$phppear->testmode($sourcedir);
 $phppear->pre_building_step();
 $phppear->install($destdir);
 if (!-f "$destdir/usr/share/doc/php-foo/package.xml") {
@@ -82,11 +82,11 @@ if ($file_count != 13) {
 # CLEAN pearpkg1
 # =============================================================================
 $phppear = Debian::Debhelper::Buildsystem::phppear->new();
-$phppear->{phppkginfo_path} = "$orig_dir/share/pkg-php-tools/scripts/phppkginfo";
+$phppear->testmode($sourcedir);
 $phppear->pre_building_step();
 $phppear->clean();
-if (-f "MyProject_Packages-0.0.1/package.xml") {
-	print "FAIL: File should not exists: MyProject_Packages-0.0.1/package.xml\n";
+if (-f "MyProject_Packages-1.2.1/package.xml") {
+	print "FAIL: File should not exists: MyProject_Packages-1.2.1/package.xml\n";
 	$failures++;
 }
 
